<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class UsuarioController extends Controller
{
    public function index(Request $request)
    {
        $query = DB::table('usuarios');

        if ($request->filled('nome')) {
            $query->where('nome', 'like', '%' . $request->nome . '%');
        }

        if ($request->filled('nivel')) {
            $query->where('nivel_acesso', $request->nivel);
        }

        $usuarios = $query->paginate(10)->appends($request->query());

        return view('usuarios.index', compact('usuarios'));
    }

    public function create()
    {
        return view('usuarios.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'nome' => 'required',
            'email' => 'required|email|unique:usuarios,email',
            'senha' => 'required|min:6',
            'nivel_acesso' => 'required',
        ]);

        DB::table('usuarios')->insert([
            'nome' => $request->nome,
            'email' => $request->email,
            'senha' => bcrypt($request->senha),
            'nivel_acesso' => $request->nivel_acesso,
            'telefone' => $request->telefone,
            'ativo' => 1,
            'data_cadastro' => now(),
        ]);

        return redirect()->route('usuarios.index')->with('success', 'Usuário criado com sucesso.');
    }

    public function edit($id)
    {
        $usuario = DB::table('usuarios')->where('id', $id)->first();
        return view('usuarios.edit', compact('usuario'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'nome' => 'required',
            'email' => 'required|email',
            'nivel_acesso' => 'required',
        ]);

        DB::table('usuarios')->where('id', $id)->update([
            'nome' => $request->nome,
            'email' => $request->email,
            'nivel_acesso' => $request->nivel_acesso,
            'telefone' => $request->telefone,
        ]);

        return redirect()->route('usuarios.index')->with('success', 'Usuário atualizado com sucesso.');
    }

    public function destroy($id)
    {
        DB::table('usuarios')->where('id', $id)->delete();
        return redirect()->route('usuarios.index')->with('success', 'Usuário excluído com sucesso.');
    }
}
