<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;

class UsuarioController extends Controller
{
    public function index(Request $request)
    {
        $query = DB::table('usuarios');

        if ($request->filled('nome')) {
            $query->where('nome', 'like', '%' . $request->nome . '%');
        }

        if ($request->filled('nivel')) {
            $query->where('nivel_acesso', $request->nivel);
        }

        $usuarios = $query->get();

        return view('usuarios.index', compact('usuarios'));
    }

    public function create()
    {
        return view('usuarios.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'nome' => 'required',
            'email' => 'required|email|unique:usuarios,email',
            'senha' => 'required|min:6',
            'nivel_acesso' => 'required',
        ]);

        DB::table('usuarios')->insert([
            'nome' => $request->nome,
            'email' => $request->email,
            'senha' => Hash::make($request->senha),
            'nivel_acesso' => $request->nivel_acesso,
            'telefone' => $request->telefone,
            'ativo' => $request->filled('ativo') ? 1 : 0,
            'data_cadastro' => now(),
        ]);

        return redirect()->route('usuarios.index')->with('success', 'Usuário criado com sucesso.');
    }
    
    public function index()
{
    $usuarios = Usuario::paginate(10);
    return view('usuarios.index', compact('usuarios'));
}

    
    public function edit($id)
    {
        $usuario = DB::table('usuarios')->where('id', $id)->first();
        return view('usuarios.edit', compact('usuario'));
    }

    public function update(Request $request, $id)
    {
        $data = [
            'nome' => $request->nome,
            'email' => $request->email,
            'nivel_acesso' => $request->nivel_acesso,
            'telefone' => $request->telefone,
            'ativo' => $request->filled('ativo') ? 1 : 0,
        ];

        if ($request->filled('senha')) {
            $data['senha'] = Hash::make($request->senha);
        }

        DB::table('usuarios')->where('id', $id)->update($data);

        return redirect()->route('usuarios.index')->with('success', 'Usuário atualizado com sucesso.');
    }

    public function destroy($id)
    {
        DB::table('usuarios')->where('id', $id)->delete();
        return redirect()->route('usuarios.index')->with('success', 'Usuário excluído com sucesso.');
    }
}
