<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;

class UsuarioController extends Controller
{
    public function index(Request $request)
    {
        $query = DB::table('usuarios');

        if ($request->filled('nome')) {
            $query->where('nome', 'like', '%' . $request->nome . '%');
        }

        if ($request->filled('nivel')) {
            $query->where('nivel_acesso', $request->nivel);
        }

        $usuarios = $query->get();

        return view('usuarios.index', compact('usuarios'));
    }

    public function create()
    {
        return view('usuarios.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'nome' => 'required|string|max:100',
            'email' => 'required|email|unique:usuarios,email',
            'senha' => 'required|string|min:6',
            'nivel_acesso' => 'required|in:admin,gerente,tecnico,atendente',
        ]);

        DB::table('usuarios')->insert([
            'nome' => $request->nome,
            'email' => $request->email,
            'senha' => Hash::make($request->senha),
            'nivel_acesso' => $request->nivel_acesso,
            'telefone' => $request->telefone,
            'ativo' => $request->filled('ativo') ? 1 : 0,
            'data_cadastro' => now(),
        ]);

        return redirect()->route('usuarios.index')->with('success', 'Usuário cadastrado com sucesso.');
    }
}
