<?php

namespace App\Http\Controllers;

use App\Models\Usuario;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class UsuarioController extends Controller
{
    public function index(Request $request)
    {
        $query = Usuario::query();

        if ($request->filled('nome')) {
            $query->where('nome', 'like', '%' . $request->nome . '%');
        }

        if ($request->filled('nivel_acesso')) {
            $query->where('nivel_acesso', $request->nivel_acesso);
        }

        $usuarios = $query->paginate(10)->withQueryString();
        return view('usuarios.index', compact('usuarios'));
    }

    public function create()
    {
        $this->authorizeAdmin();
        return view('usuarios.create');
    }

    public function store(Request $request)
    {
        $this->authorizeAdmin();
        $data = $request->validate([
            'nome' => 'required|string|max:100',
            'email' => 'required|email|unique:usuarios,email',
            'senha' => 'required|string|min:6',
            'nivel_acesso' => 'required|in:admin,gerente,tecnico,atendente',
        ]);

        $data['senha'] = bcrypt($data['senha']);
        Usuario::create($data);
        return redirect()->route('usuarios.index')->with('success', 'Usuário cadastrado!');
    }

    public function edit(Usuario $usuario)
    {
        $this->authorizeAdmin();
        return view('usuarios.edit', compact('usuario'));
    }

    public function update(Request $request, Usuario $usuario)
    {
        $this->authorizeAdmin();
        $data = $request->validate([
            'nome' => 'required|string|max:100',
            'email' => 'required|email|unique:usuarios,email,' . $usuario->id,
            'nivel_acesso' => 'required|in:admin,gerente,tecnico,atendente',
        ]);

        if ($request->filled('senha')) {
            $data['senha'] = bcrypt($request->senha);
        }

        $usuario->update($data);
        return redirect()->route('usuarios.index')->with('success', 'Usuário atualizado!');
    }

    private function authorizeAdmin()
    {
        if (Auth::user()->nivel_acesso ?? 'atendente' !== 'admin') {
            abort(403, 'Acesso não autorizado');
        }
    }
}
