<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class ClienteController extends Controller
{
    public function index(Request $request)
    {
        $query = DB::table('clientes')->orderBy('nome_fantasia');

        if ($request->filled('tipo')) {
            $query->where('tipo', $request->tipo);
        }

        if ($request->filled('cpf_cnpj')) {
            $query->where('cpf_cnpj', 'like', '%' . $request->cpf_cnpj . '%');
        }

        if ($request->filled('nome')) {
            $query->where(function ($q) use ($request) {
                $q->where('nome_completo', 'like', '%' . $request->nome . '%')
                  ->orWhere('razao_social', 'like', '%' . $request->nome . '%');
            });
        }

        $clientes = $query->paginate(10)->appends($request->query());

        return view('clientes.index', compact('clientes'));
    }

    public function create()
    {
        return view('clientes.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'tipo' => 'required|in:PF,PJ',
            'cpf_cnpj' => 'required|unique:clientes',
            'email' => 'nullable|email',
        ]);

        $clienteId = DB::table('clientes')->insertGetId([
            'tipo' => $request->tipo,
            'cpf_cnpj' => $request->cpf_cnpj,
            'nome_completo' => $request->tipo == 'PF' ? $request->nome_completo : null,
            'razao_social' => $request->tipo == 'PJ' ? $request->razao_social : null,
            'nome_fantasia' => $request->tipo == 'PJ' ? $request->nome_fantasia : null,
            'rg' => $request->rg,
            'data_nascimento' => $request->data_nascimento,
            'email' => $request->email,
            'telefone_principal' => $request->telefone_principal,
            'cep' => $request->cep,
            'logradouro' => $request->logradouro,
            'numero' => $request->numero,
            'bairro' => $request->bairro,
            'cidade' => $request->cidade,
            'estado' => $request->estado,
            'tipo_unidade' => $request->tipo_unidade,
            'ativo' => 1,
            'data_cadastro' => now(),
        ]);

        if ($request->filled('numero_contrato')) {
            DB::table('contratos')->insert([
                'cliente_id' => $clienteId,
                'numero_contrato' => $request->numero_contrato,
                'descricao' => $request->descricao_contrato,
                'data_inicio' => $request->data_inicio,
                'data_fim' => $request->data_fim,
                'valor' => $request->valor,
                'status' => $request->status,
                'renovacao_automatica' => $request->renovacao_automatica ? 1 : 0,
                'tipo_contrato_id' => $request->tipo_contrato_id,
                'usuario_responsavel_id' => auth()->id(),
                'data_cadastro' => now(),
            ]);
        }

        return redirect()->route('clientes.index')->with('success', 'Cliente e contrato cadastrados com sucesso.');
    }

    public function edit($id)
    {
        $cliente = DB::table('clientes')->where('id', $id)->first();
        return view('clientes.edit', compact('cliente'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'email' => 'nullable|email',
            'cpf_cnpj' => 'required',
        ]);

        DB::table('clientes')->where('id', $id)->update([
            'email' => $request->email,
            'telefone_principal' => $request->telefone_principal,
            'cep' => $request->cep,
            'logradouro' => $request->logradouro,
            'numero' => $request->numero,
            'bairro' => $request->bairro,
            'cidade' => $request->cidade,
            'estado' => $request->estado,
        ]);

        return redirect()->route('clientes.index')->with('success', 'Cliente atualizado com sucesso.');
    }

    public function destroy($id)
    {
        DB::table('clientes')->where('id', $id)->delete();
        return redirect()->route('clientes.index')->with('success', 'Cliente removido com sucesso.');
    }
}
