@extends('layouts.app')

@section('content')
<div class="container mx-auto px-4 py-6">
    <div class="flex justify-between items-center mb-6"><h1 class="text-2xl font-bold text-gray-800">Usuários do Sistema</h1><a href="{{ route('usuarios.create') }}" class="bg-green-600 text-white px-4 py-2 rounded-lg hover:bg-green-700">+ Criar</a></div>

    <form method="GET" action="{{ route('usuarios.index') }}" class="flex flex-wrap gap-4 mb-6">
        <input type="text" name="nome" value="{{ request('nome') }}" placeholder="Nome do usuário"
            class="px-4 py-2 border border-gray-300 rounded-lg shadow-sm focus:outline-none focus:ring focus:border-blue-500">

        <select name="nivel" class="px-4 py-2 border border-gray-300 rounded-lg shadow-sm focus:outline-none focus:ring focus:border-blue-500">
            <option value="">Todos os níveis</option>
            <option value="admin" {{ request('nivel') == 'admin' ? 'selected' : '' }}>Admin</option>
            <option value="gerente" {{ request('nivel') == 'gerente' ? 'selected' : '' }}>Gerente</option>
            <option value="tecnico" {{ request('nivel') == 'tecnico' ? 'selected' : '' }}>Técnico</option>
            <option value="atendente" {{ request('nivel') == 'atendente' ? 'selected' : '' }}>Atendente</option>
        </select>

        <button type="submit" class="bg-blue-600 text-white px-4 py-2 rounded-lg hover:bg-blue-700 transition">
            Filtrar
        </button>
    </form>

    <div class="overflow-x-auto bg-white shadow-md rounded-lg">
        <table class="min-w-full table-auto">
            <thead class="bg-gray-100 text-gray-700 text-left text-sm uppercase">
                <tr>
                    <th class="px-6 py-3">Nome</th>
                    <th class="px-6 py-3">Email</th>
                    <th class="px-6 py-3">Nível de Acesso</th>
                    <th class="px-6 py-3">Ações</th>
                </tr>
            </thead>
            <tbody class="text-gray-800">
                @forelse ($usuarios as $usuario)
                <tr class="border-t hover:bg-gray-50">
                    <td class="px-6 py-4">{{ $usuario->nome }}</td>
                    <td class="px-6 py-4">{{ $usuario->email }}</td>
                    <td class="px-6 py-4 capitalize">{{ $usuario->nivel_acesso }}</td>
                    <td class="px-6 py-4">
                        <a href="{{ route('usuarios.edit', $usuario->id) }}" class="text-blue-600 hover:underline mr-4">Editar</a>
                        <form action="{{ route('usuarios.destroy', $usuario->id) }}" method="POST" class="inline-block" onsubmit="return confirm('Tem certeza que deseja excluir?');">
                            @csrf
                            @method('DELETE')
                            <button type="submit" class="text-red-600 hover:underline">Excluir</button>
                        </form>
                    </td>
                </tr>
                @empty
                <tr>
                    <td colspan="4" class="px-6 py-4 text-center text-gray-500">Nenhum usuário encontrado.</td>
                </tr>
                @endforelse
            </tbody>
        </table>
    </div>

    <div class="mt-6">
        {{ $usuarios->withQueryString()->links() }}
    </div>
</div>
@endsection
