@extends('layouts.app')

@section('content')
<div class="container mx-auto px-4">
    <div class="flex items-center justify-between mb-4">
        <h1 class="text-2xl font-bold text-gray-800">Usuários do Sistema</h1>
        <a href="{{ route('usuarios.create') }}" class="bg-blue-600 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded">
            + Novo Usuário
        </a>
    </div>

    <form method="GET" action="{{ route('usuarios.index') }}" class="flex items-center space-x-4 mb-4">
        <input type="text" name="nome" value="{{ request('nome') }}" placeholder="Buscar por nome"
               class="border border-gray-300 rounded px-3 py-2 w-64">
        <select name="nivel" class="border border-gray-300 rounded px-3 py-2">
            <option value="">Todos os níveis</option>
            <option value="admin" {{ request('nivel') == 'admin' ? 'selected' : '' }}>Admin</option>
            <option value="gerente" {{ request('nivel') == 'gerente' ? 'selected' : '' }}>Gerente</option>
            <option value="tecnico" {{ request('nivel') == 'tecnico' ? 'selected' : '' }}>Técnico</option>
            <option value="atendente" {{ request('nivel') == 'atendente' ? 'selected' : '' }}>Atendente</option>
        </select>
        <button type="submit" class="bg-gray-700 hover:bg-gray-800 text-white px-4 py-2 rounded">Filtrar</button>
    </form>

    <div class="overflow-x-auto bg-white rounded shadow">
        <table class="min-w-full text-sm text-left text-gray-700">
            <thead class="text-xs uppercase bg-gray-100 text-gray-600">
                <tr>
                    <th class="px-6 py-3">ID</th>
                    <th class="px-6 py-3">Nome</th>
                    <th class="px-6 py-3">Email</th>
                    <th class="px-6 py-3">Nível</th>
                    <th class="px-6 py-3">Ações</th>
                </tr>
            </thead>
            <tbody>
                @foreach ($usuarios as $usuario)
                <tr class="border-t">
                    <td class="px-6 py-4">{{ $usuario->id }}</td>
                    <td class="px-6 py-4">{{ $usuario->nome }}</td>
                    <td class="px-6 py-4">{{ $usuario->email }}</td>
                    <td class="px-6 py-4">
                        <span class="inline-block px-2 py-1 rounded text-white {{ $usuario->nivel_acesso == 'admin' ? 'bg-red-500' : ($usuario->nivel_acesso == 'gerente' ? 'bg-yellow-500' : ($usuario->nivel_acesso == 'tecnico' ? 'bg-blue-500' : 'bg-green-500')) }}">
                            {{ ucfirst($usuario->nivel_acesso) }}
                        </span>
                    </td>
                    <td class="px-6 py-4 flex space-x-2">
                        <a href="{{ route('usuarios.edit', $usuario->id) }}" class="text-blue-500 hover:underline">✏️ Editar</a>
                        <form method="POST" action="{{ route('usuarios.destroy', $usuario->id) }}" onsubmit="return confirm('Tem certeza que deseja excluir este usuário?')">
                            @csrf
                            @method('DELETE')
                            <button type="submit" class="text-red-500 hover:underline">🗑️ Excluir</button>
                        </form>
                    </td>
                </tr>
                @endforeach
            </tbody>
        </table>
    </div>
</div>
@endsection
