@extends('layouts.app')

@section('title', 'Usuários')

@section('content')
<h2 class="text-xl font-bold mb-4">Usuários do Sistema</h2>

<form method="GET" class="mb-4 flex items-center gap-4">
    <input type="text" name="nome" placeholder="Buscar por nome" value="{{ request('nome') }}" class="p-2 border rounded">
    <select name="nivel_acesso" class="p-2 border rounded">
        <option value="">Todos os níveis</option>
        @foreach(['admin', 'gerente', 'tecnico', 'atendente'] as $nivel)
            <option value="{{ $nivel }}" {{ request('nivel_acesso') == $nivel ? 'selected' : '' }}>
                {{ ucfirst($nivel) }}
            </option>
        @endforeach
    </select>
    <button type="submit" class="bg-blue-600 text-white px-4 py-2 rounded">Filtrar</button>
</form>

@auth
    @if(Auth::user()->nivel_acesso === 'admin')
        <a href="{{ route('usuarios.create') }}" class="bg-green-600 text-white px-4 py-2 rounded mb-4 inline-block">Novo Usuário</a>
    @endif
@endauth

@if(session('success'))
    <div class="bg-green-200 p-2 rounded text-green-800 mb-2">
        {{ session('success') }}
    </div>
@endif

<table class="table-auto w-full border mb-4">
    <thead>
        <tr>
            <th class="border p-2">ID</th>
            <th class="border p-2">Nome</th>
            <th class="border p-2">Email</th>
            <th class="border p-2">Nível</th>
            <th class="border p-2">Ações</th>
        </tr>
    </thead>
    <tbody>
        @foreach ($usuarios as $usuario)
        <tr>
            <td class="border p-2">{{ $usuario->id }}</td>
            <td class="border p-2">{{ $usuario->nome }}</td>
            <td class="border p-2">{{ $usuario->email }}</td>
            <td class="border p-2">{{ $usuario->nivel_acesso }}</td>
            <td class="border p-2">
                @if(Auth::user()->nivel_acesso === 'admin')
                    <a href="{{ route('usuarios.edit', $usuario) }}" class="text-blue-600 hover:underline">Editar</a>
                @else
                    <span class="text-gray-400">Restrito</span>
                @endif
            </td>
        </tr>
        @endforeach
    </tbody>
</table>

{{ $usuarios->links() }}
@endsection
