<?php

use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use App\Http\Controllers\UsuarioController;
use App\Http\Controllers\ClienteController;

Route::get('/', fn() => view('auth.login'))->name('login');
Route::get('/dashboard', fn() => view('dashboard.index'))->middleware(['auth'])->name('dashboard');
Route::get('/debug-auth', function () {
    return Auth::check() ? '✅ Autenticado como ' . Auth::user()->email : '❌ Não autenticado';
});

Route::get('/testar-users', function () {
    return DB::table('users')->get();
});

Route::get('/forcar-login', function () {
    $user = \App\Models\User::where('email', 'admin@sulredesti.com')->first();
    Auth::login($user);
    return redirect('/dashboard');
});

Route::get('/login-select', function () {
    $usuarios = User::all();
    return view('auth.login-select', compact('usuarios'));
});

Route::post('/login-custom', function (\Illuminate\Http\Request $request) {
    $credentials = $request->only('email', 'password');
    if (Auth::attempt($credentials, $request->remember)) {
        return redirect()->intended('/dashboard');
    }

    return back()->withErrors([
        'email' => 'Credenciais inválidas.',
    ]);
})->name('login.custom');

Route::view('/login-debug', 'auth.debug-login');

Route::post('/login-debug', function (Request $request) {
    $email = $request->email;
    $senha = $request->password;

    $user = User::where('email', $email)->first();

    if (!$user) {
        return '❌ Usuário não encontrado: ' . $email;
    }

    if (!Hash::check($senha, $user->password)) {
        return '❌ Senha incorreta para ' . $email;
    }

    if (Auth::attempt(['email' => $email, 'password' => $senha])) {
        return '✅ Login AUTENTICADO com sucesso para ' . $email;
    } else {
        return '❌ Auth::attempt falhou, mesmo com senha válida.';
    }
});

Route::middleware('auth')->group(function () {
    Route::get('/usuarios', [UsuarioController::class, 'index'])->name('usuarios.index');
    Route::get('/usuarios/create', [UsuarioController::class, 'create'])->name('usuarios.create');
    Route::post('/usuarios', [UsuarioController::class, 'store'])->name('usuarios.store');
    Route::get('/usuarios/{id}/edit', [UsuarioController::class, 'edit'])->name('usuarios.edit');
    Route::put('/usuarios/{id}', [UsuarioController::class, 'update'])->name('usuarios.update');
    Route::delete('/usuarios/{id}', [UsuarioController::class, 'destroy'])->name('usuarios.destroy');
});

Route::middleware(['auth'])->group(function () {
    Route::get('/clientes', [ClienteController::class, 'index'])->name('clientes.index');
    Route::get('/clientes/create', [ClienteController::class, 'create'])->name('clientes.create');
    Route::post('/clientes', [ClienteController::class, 'store'])->name('clientes.store');
    Route::get('/clientes/{id}/edit', [ClienteController::class, 'edit'])->name('clientes.edit');
    Route::put('/clientes/{id}', [ClienteController::class, 'update'])->name('clientes.update');
    Route::delete('/clientes/{id}', [ClienteController::class, 'destroy'])->name('clientes.destroy');
});


require __DIR__.'/auth.php';
require __DIR__.'/usuarios.php';
require __DIR__.'/dashboard.php';

