<?php

use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use App\Http\Controllers\UsuarioController;
use App\Http\Controllers\ClienteController;

// Rotas públicas
Route::get('/', fn() => view('auth.login'))->name('login');

// Rotas de depuração (considere remover em produção)
Route::get('/debug-auth', function () {
    return Auth::check() ? '✅ Autenticado como ' . Auth::user()->email : '❌ Não autenticado';
});

Route::get('/testar-users', function () {
    return DB::table('users')->get();
});

Route::get('/forcar-login', function () {
    $user = User::where('email', 'admin@sulredesti.com')->first();
    Auth::login($user);
    return redirect('/dashboard');
});

// Rotas de autenticação personalizadas
Route::get('/login-select', function () {
    $usuarios = User::all();
    return view('auth.login-select', compact('usuarios'));
});

Route::post('/login-custom', function (Request $request) {
    $credentials = $request->only('email', 'password');
    if (Auth::attempt($credentials, $request->remember)) {
        return redirect()->intended('/dashboard');
    }
    return back()->withErrors(['email' => 'Credenciais inválidas.']);
})->name('login.custom');

Route::view('/login-debug', 'auth.debug-login');
Route::post('/login-debug', function (Request $request) {
    $email = $request->email;
    $senha = $request->password;
    $user = User::where('email', $email)->first();

    if (!$user) {
        return '❌ Usuário não encontrado: ' . $email;
    }
    if (!Hash::check($senha, $user->password)) {
        return '❌ Senha incorreta para ' . $email;
    }
    if (Auth::attempt(['email' => $email, 'password' => $senha])) {
        return '✅ Login AUTENTICADO com sucesso para ' . $email;
    } else {
        return '❌ Auth::attempt falhou, mesmo com senha válida.';
    }
});

// Rotas protegidas por autenticação
Route::middleware('auth')->group(function () {
    Route::get('/dashboard', fn() => view('dashboard.index'))->name('dashboard');

    // Rotas de Usuários
    Route::prefix('usuarios')->group(function () {
        Route::get('/', [UsuarioController::class, 'index'])->name('usuarios.index');
        Route::get('/create', [UsuarioController::class, 'create'])->name('usuarios.create');
        Route::post('/', [UsuarioController::class, 'store'])->name('usuarios.store');
        Route::get('/{id}/edit', [UsuarioController::class, 'edit'])->name('usuarios.edit');
        Route::put('/{id}', [UsuarioController::class, 'update'])->name('usuarios.update');
        Route::delete('/{id}', [UsuarioController::class, 'destroy'])->name('usuarios.destroy');
    });

    // Rotas de Clientes
    Route::prefix('clientes')->group(function () {
        Route::get('/', [ClienteController::class, 'index'])->name('clientes.index');
        Route::get('/create', [ClienteController::class, 'create'])->name('clientes.create');
        Route::post('/', [ClienteController::class, 'store'])->name('clientes.store');
        Route::get('/{id}/edit', [ClienteController::class, 'edit'])->name('clientes.edit');
        Route::put('/{id}', [ClienteController::class, 'update'])->name('clientes.update');
        Route::delete('/{id}', [ClienteController::class, 'destroy'])->name('clientes.destroy');
    });
});

// Inclusão de arquivos de rotas adicionais
require __DIR__.'/auth.php';
require __DIR__.'/usuarios.php';
require __DIR__.'/dashboard.php';